[![build](https://github.com/crvernon/atiim/actions/workflows/build.yml/badge.svg)](https://github.com/crvernon/atiim/actions/workflows/build.yml)
[![codecov](https://codecov.io/gh/crvernon/atiim/branch/main/graph/badge.svg?token=MUYY7WOGCP)](https://codecov.io/gh/crvernon/atiim)
[![DOI](https://zenodo.org/badge/DOI/10.5281/zenodo.5823541.svg)](https://doi.org/10.5281/zenodo.5823541)
[![docs](https://github.com/crvernon/atiim/actions/workflows/pages/pages-build-deployment/badge.svg)](https://github.com/crvernon/atiim/actions/workflows/pages/pages-build-deployment)
[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/crvernon/atiim/main?labpath=notebooks%2Fquickstarter.ipynb)

# atiim
#### The Area Time Inundation Index Model

### Purpose
`atiim` is the Area-Time Inundatation Index Model which was created to address the challenge of rapidly characterizing spatiotemporally-complex inundation patterns in dynamic systems, such as estuarine tidal-fluvial environments.

### Install `atiim`

```bash
pip install atiim
```

### Check out a quickstart tutorial to run `atiim`

Run `atiim` using the quicktart tutorial: [`atiim` Quickstarter](https://mybinder.org/v2/gh/crvernon/atiim/main?labpath=notebooks%2Fquickstarter.ipynb)

### Getting started

New to `atiim`?  Get familiar with what `atiim` is all about in our [Getting Started](https://crvernon.github.io/atiim/getting_started.html) docs!

### User guide

Our user guide provides in-depth information on the key concepts of `atiim` with useful background information and explanation.  See our [User Guide](www.google.com)

### Contributing to `atiim`

Whether you find a typo in the documentation, find a bug, or want to develop functionality that you think will make `atiim` more robust, you are welcome to contribute! See our [Contribution Guidelines](www.google.com)

### API reference
The reference guide contains a detailed description of the `atiim` API.  The reference describes how the methods work and which parameters can be used.  It assumes that you have an understanding of the key concepts.  See [API Reference](https://crvernon.github.io/atiim/atiim.html)
